@@ -11,12 +11,16 @@ enumeration.
 from .http.http import HttpEnumeration
 from .ftp.ftp import FtpEnumeration
 from .nbt.nbt import NbtEnumeration
+from .telnet.telnet import TelnetEnumeration
 
 http = HttpEnumeration()
 ftp = FtpEnumeration()
 nbt = NbtEnumeration()
+telnet = TelnetEnumeration
+
 service_modules = [http, ftp, nbt]
 
+
 def receive_service_data(sender=None, **flags):
     """Receive data either directly (not implemented) or via signal. Delegate 
     service enumeration depending on reported services.
