@@ -6,10 +6,12 @@ enumeration tasks.
 @author: Steve Coward (steve<at>sugarstack.io)
 @version: 1.0
 """
-import os, sys
+import os
+import sys
 from ..process_manager import ProcessManager
 from ..generic_service import GenericService
 
+
 class FtpEnumeration(GenericService, ProcessManager):
     LIB_PATH = os.path.dirname(os.path.realpath(__file__))
     SERVICE_DEFINITION = 'service:ftp'
@@ -32,7 +34,7 @@ class FtpEnumeration(GenericService, ProcessManager):
         @param service_parameters: Dictionary with
         key:value pairs of service-related data.
         """
-        
+
         for process in self.PROCESSES:
             self.start_processes(process, params={
                 'host': service_parameters.get('ip'),
